==> haskell-ipython-kernel-0.11.0.0-135-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ipython-kernel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ipython-kernel
version:              0.11.0.0
visibility:           public
id:                   ipython-kernel-0.11.0.0-I7z5eA5wUtv870g5gLkIvg
key:                  ipython-kernel-0.11.0.0-I7z5eA5wUtv870g5gLkIvg
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A library for creating kernels for IPython frontends
description:
    ipython-kernel is a library for communicating with frontends for the interactive IPython framework. It is used extensively in IHaskell, the interactive Haskell environment.

category:             Development
abi:                  2fe0ad41609a437afa21aaeaed18f44b
exposed:              True
exposed-modules:
    IHaskell.IPython.EasyKernel IHaskell.IPython.Kernel
    IHaskell.IPython.Message.Parser IHaskell.IPython.Message.UUID
    IHaskell.IPython.Types IHaskell.IPython.ZeroMQ

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipython-kernel
hs-libraries:         HSipython-kernel-0.11.0.0-I7z5eA5wUtv870g5gLkIvg
depends:
    aeson-2.1.2.1-HvDDR856aNq5cfhhuYXFVB base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-9KIGERGrT4cFXpK0jxnTMg directory-1.3.7.1
    filepath-1.4.2.2 memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    parsec-3.1.16.1 process-1.6.18.0
    temporary-1.3-Hhl2LRPiMvQ4xmTU7fPXaD text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-8cMd7edANcDBeBDjVdjsZY
    uuid-1.3.16-GJSG7HiE4PXIztKocWTNuc
    zeromq4-haskell-0.8.0-Cn1ne6Zefr4J9JPM7zt8FA

haddock-interfaces:
    /usr/share/doc/haskell-ipython-kernel/html/ipython-kernel.haddock

haddock-html:         /usr/share/doc/haskell-ipython-kernel/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ipython-kernel-0.11.0.0-136-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ipython-kernel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ipython-kernel
version:              0.11.0.0
visibility:           public
id:                   ipython-kernel-0.11.0.0-EC1pHF1Vavk6zVnHlrtiB9
key:                  ipython-kernel-0.11.0.0-EC1pHF1Vavk6zVnHlrtiB9
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A library for creating kernels for IPython frontends
description:
    ipython-kernel is a library for communicating with frontends for the interactive IPython framework. It is used extensively in IHaskell, the interactive Haskell environment.

category:             Development
abi:                  ae400fd5acd49f17b599b01563d4dafd
exposed:              True
exposed-modules:
    IHaskell.IPython.EasyKernel IHaskell.IPython.Kernel
    IHaskell.IPython.Message.Parser IHaskell.IPython.Message.UUID
    IHaskell.IPython.Types IHaskell.IPython.ZeroMQ

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipython-kernel
hs-libraries:         HSipython-kernel-0.11.0.0-EC1pHF1Vavk6zVnHlrtiB9
depends:
    aeson-2.1.2.1-9cza8YJPY5Z8Ze3x8zf5ig base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-9KIGERGrT4cFXpK0jxnTMg directory-1.3.7.1
    filepath-1.4.2.2 memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    parsec-3.1.16.1 process-1.6.18.0
    temporary-1.3-Hhl2LRPiMvQ4xmTU7fPXaD text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-8cMd7edANcDBeBDjVdjsZY
    uuid-1.3.16-GJSG7HiE4PXIztKocWTNuc
    zeromq4-haskell-0.8.0-Cn1ne6Zefr4J9JPM7zt8FA

haddock-interfaces:
    /usr/share/doc/haskell-ipython-kernel/html/ipython-kernel.haddock

haddock-html:         /usr/share/doc/haskell-ipython-kernel/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
